netapp_ontap.models.storage_bridge_temperature_sensor API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_bridge_temperature_sensor`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StorageBridgeTemperatureSensorSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StorageBridgeTemperatureSensor object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `maximum: Size GET POST PATCH`

    Maximum safe operating temperature, in degrees Celsius.

  `minimum: Size GET POST PATCH`

    Minimum safe operating temperature, in degrees Celsius.

  `name: str GET POST PATCH`

    Temperature sensor name

    Example: Chassis temperature sensor

  `reading: Size GET POST PATCH`

    Chassis temperature sensor reading, in degrees Celsius.

  `state: str GET POST PATCH`

    The state field of the storage_bridge_temperature_sensor.

    Valid choices:

    - ok
    - warning
    - error